@@ -190,11 +190,16 @@ class AssertTypeProperty(JsonProperty):
         if not isinstance(obj, self._type):
             raise BadValueError('{0} not of type {1}'.format(obj, self._type))
 
+    def selective_coerce(self, obj):
+        return obj
+
     def wrap(self, obj):
+        obj = self.selective_coerce(obj)
         self.assert_type(obj)
         return obj
 
     def unwrap(self, obj):
+        obj = self.selective_coerce(obj)
         self.assert_type(obj)
         return obj, obj
 
@@ -716,7 +721,12 @@ class _LimitedDictInterfaceMixin(object):
 
 
 class JsonObject(JsonObjectBase, _LimitedDictInterfaceMixin):
-    pass
+
+    def __getstate__(self):
+        return self.to_json()
+
+    def __setstate__(self, dct):
+        self.__init__(dct)
 
 
 def get_dynamic_properties(obj):
